/*
 * Created on Mar 22, 2008
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.common;

import java.io.Serializable;

/**
 * This class contains the property of the chart that is displayed by a
 * {@link org.cafesip.gwtcomp.client.ui.charting.LiveDataPanel} component. The
 * client-side constructs the chart based on the properties set an object of
 * this type.
 * 
 * @author Amit Chatterjee
 * 
 */
public class ChartInfo implements Serializable
{
    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = -2124130079828261532L;

    private String title;

    private boolean displayLegend = true;

    private PlotInfo plot;

    private int rowsToDisplay = 0;

    /**
     * 
     * A constructor for this class.
     * 
     */
    public ChartInfo()
    {
    }

    /**
     * A constructor for this class.
     * 
     * @param title
     *            title of the data panel
     * @param displayLegend
     *            whether the legend must be displayed or not
     * @param plot
     *            plot information
     * @param numDataRows
     *            number of rows to display. Each row contains the data for a
     *            given point of time. If the value greater than 0 is specified,
     *            a table containing the live data is displayed in addition to
     *            the chart. For example, if a value of 5 is specified, the
     *            table displays the data for the last five intervals.
     */
    public ChartInfo(String title, boolean displayLegend, PlotInfo plot,
            int numDataRows)
    {
        this.title = title;
        this.displayLegend = displayLegend;
        this.plot = plot;
        this.rowsToDisplay = numDataRows;
    }

    /**
     * @return Returns the title.
     */
    public String getTitle()
    {
        return title;
    }

    /**
     * @param title
     *            The title to set.
     */
    public void setTitle(String title)
    {
        this.title = title;
    }

    /**
     * @return Returns the displayLegend.
     */
    public boolean isDisplayLegend()
    {
        return displayLegend;
    }

    /**
     * @param displayLegend
     *            The displayLegend to set.
     */
    public void setDisplayLegend(boolean displayLegend)
    {
        this.displayLegend = displayLegend;
    }

    /**
     * @return Returns the plot.
     */
    public PlotInfo getPlot()
    {
        return plot;
    }

    /**
     * @param plot
     *            The plot to set.
     */
    public void setPlot(PlotInfo plot)
    {
        this.plot = plot;
    }

    /**
     * @return Returns the rowsToDisplay.
     */
    public int getRowsToDisplay()
    {
        return rowsToDisplay;
    }

    /**
     * @param rowsToDisplay
     *            The rowsToDisplay to set.
     */
    public void setRowsToDisplay(int rowsToDisplay)
    {
        this.rowsToDisplay = rowsToDisplay;
    }

}
