/*
 * Created on Mar 22, 2008
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.common;

import java.io.Serializable;

/**
 * This class contains the property of the chart that is displayed by a
 * {@link org.cafesip.gwtcomp.client.ui.charting.LiveDataPanel} component and
 * the initial data set. The client-side constructs the chart based on the
 * properties set an object of this type.
 * 
 * @author Amit Chatterjee
 * 
 */
public class ChartInitData implements Serializable
{
    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = 2646959728601391841L;

    private ChartInfo chartData;

    private ChartData initialData;

    private int sessionId;

    /**
     * 
     * A constructor for this class.
     * 
     */
    public ChartInitData()
    {
    }

    /**
     * A constructor for this class.
     * 
     * @param chartData
     *            contains the properties of the chart
     * @param initialData
     *            contains the initial data that is displayed when the chart is
     *            displayed.
     */
    public ChartInitData(ChartInfo chartData, ChartData initialData)
    {
        this.chartData = chartData;
        this.initialData = initialData;
    }

    /**
     * @return Returns the chartData.
     */
    public ChartInfo getChartData()
    {
        return chartData;
    }

    /**
     * @param chartData
     *            The chartData to set.
     */
    public void setChartData(ChartInfo chartData)
    {
        this.chartData = chartData;
    }

    /**
     * @return Returns the initialData.
     */
    public ChartData getInitialData()
    {
        return initialData;
    }

    /**
     * @param initialData
     *            The initialData to set.
     */
    public void setInitialData(ChartData initialData)
    {
        this.initialData = initialData;
    }

    /**
     * @return Returns the sessionId.
     */
    public int getSessionId()
    {
        return sessionId;
    }

    /**
     * @param sessionId
     *            The sessionId to set.
     */
    public void setSessionId(int sessionId)
    {
        this.sessionId = sessionId;
    }
}
