/*
 * Created on Mar 22, 2008
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.common;

import java.io.Serializable;
import java.util.Date;

/**
 * This class is used for passing data for a given plot to be displayed by the
 * {@link org.cafesip.gwtcomp.client.ui.charting.LiveDataService} component.
 * 
 * @author Amit Chatterjee
 * 
 */
public class TimeSeriesPlotData implements ChartDataElement, PlotInfo, Serializable
{
    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = 353101342834463504L;

    private Date timestamp;

    private Double value[];

    /**
     * 
     * A constructor for this class.
     * 
     */
    public TimeSeriesPlotData()
    {
    }

    /**
     * A constructor for this class.
     * 
     * @param timestamp
     *            timestamp for the data point.
     * @param value
     *            the data, each element of the array represents the Y-value for
     *            a series. If your plot has 3 series, the array must have 3
     *            elements representing the value for each series at the give
     *            time.
     */
    public TimeSeriesPlotData(Date timestamp, Double[] value)
    {
        this.timestamp = timestamp;
        this.value = value;
    }

    /**
     * @return Returns the timestamp.
     */
    public Date getTimestamp()
    {
        return timestamp;
    }

    /**
     * @param timestamp
     *            The timestamp to set.
     */
    public void setTimestamp(Date timestamp)
    {
        this.timestamp = timestamp;
    }

    /**
     * @return Returns the value.
     */
    public Double[] getValue()
    {
        return value;
    }

    /**
     * @param value
     *            The value to set.
     */
    public void setValue(Double[] value)
    {
        this.value = value;
    }
}
