/*
 * Created on Aug 26, 2006
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.helpers;

import org.cafesip.gwtcomp.client.ui.ColumnProperty;

import com.google.gwt.user.client.ui.CheckBox;
import com.google.gwt.user.client.ui.ClickListener;
import com.google.gwt.user.client.ui.PopupListener;
import com.google.gwt.user.client.ui.PopupPanel;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.user.client.ui.Widget;

/**
 * Helper class for the SuperTable. 
 * 
 * 
 * @author Amit Chatterjee
 * 
 */
public class SuperTableColumnSelector extends PopupPanel
{
    private CheckBox[] checkboxes;
    
    private boolean[] checked;

    private ColumnProperty[] columns;

    private SuperTableColumnSelectorListener listener;

    /**
     *  A constructor for this class.
     * 
     *  @param columns
     *  @param listener
     */
    public SuperTableColumnSelector(ColumnProperty[] columns,
            SuperTableColumnSelectorListener listener)
    {
        super(true);
        this.columns = columns;
        this.listener = listener;
        setStyleName("gwtcomp-SuperTableColumnSelector");

        init();
    }

    private void init()
    {
        VerticalPanel p = new VerticalPanel();
        checkboxes = new CheckBox[columns.length];
        checked = new boolean[columns.length];
        for (int i = 0; i < checkboxes.length; i++)
        {
            checkboxes[i] = new CheckBox(columns[i].getHeader());
            checkboxes[i].setChecked(columns[i].isDisplayed());
            checked[i] = columns[i].isDisplayed();
                    
            class CheckboxClickListener implements ClickListener
            {
                private int i;
                public CheckboxClickListener(int i)
                {
                    this.i = i;
                }
                
                public void onClick(Widget sender)
                {
                   checked[i] = ((CheckBox)sender).isChecked();                    
                }
            }
            
            checkboxes[i].addClickListener(new CheckboxClickListener(i));
            p.add(checkboxes[i]);
        }

        add(p);

        addPopupListener(new PopupListener()
        {
           
            public void onPopupClosed(PopupPanel sender, boolean autoClosed)
            {
                boolean changed = false;
                for (int i = 0; i < SuperTableColumnSelector.this.columns.length; i++)
                {
                    if (SuperTableColumnSelector.this.columns[i]
                            .isDisplayed() != checked[i])
                    {
//                        Window.alert(SuperTableColumnSelector.this.columns[i].getHeader() 
//                                + " modified");
                        changed = true;
                        SuperTableColumnSelector.this.columns[i]
                                .setDisplayed(checked[i]);
                    }
                }

                if ((changed)
                        && (SuperTableColumnSelector.this.listener != null))
                {
                    SuperTableColumnSelector.this.listener
                            .columnSelectionChanged(SuperTableColumnSelector.this.columns);
                }
            }
        });
    }
}
