/*
 * Created on Oct 13, 2007
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Image;
import com.google.gwt.user.client.ui.PopupPanel;

/**
 * Prevents users from interacting with screen input widgets (buttons, text
 * fields, etc.) when the system is busy. The application can set itself to busy
 * or idle state by calling the static makeBusy() method.
 * 
 * @author Amit Chatterjee
 * 
 */
public class ApplicationBusy extends PopupPanel
{
    private static ApplicationBusy instance = null;

    private boolean busy = false;

    private ApplicationBusy()
    {
        super(false, true);
        setWidget(new Image(GWT.getModuleBaseURL()
                + "gwtcomp-icons/hourglass.gif"));
    }

    private static ApplicationBusy getInstance()
    {
        if (instance == null)
        {
            instance = new ApplicationBusy();
        }

        return instance;
    }

    /**
     * Sets the application to busy or idle state
     * 
     * @param busy
     *            true for busy, false for idle.
     */
    public static void makeBusy(boolean busy)
    {
        if (getInstance().isBusy() == busy)
        {
            // same as before, nothing to do
            return;
        }

        if (busy == true)
        {
            int y = (Window.getClientHeight() / 2) - 10;
            int x = (Window.getClientWidth() / 2) - 10;
            getInstance().setPopupPosition(x, y);
            getInstance().show();
        }
        else
        {
            getInstance().hide();
        }
        getInstance().setBusy(busy);
    }

    /**
     * @return Returns the busy.
     */
    private boolean isBusy()
    {
        return busy;
    }

    /**
     * @param busy
     *            The busy to set.
     */
    private void setBusy(boolean busy)
    {
        this.busy = busy;
    }

}
