/*
 * Created on Jul 23, 2006
* 
* Copyright 2005 CafeSip.org 
*
* Licensed under the Apache License, Version 2.0 (the "License"); 
* you may not use this file except in compliance with the License. 
* You may obtain a copy of the License at 
*
*	http://www.apache.org/licenses/LICENSE-2.0 
*
* Unless required by applicable law or agreed to in writing, software 
* distributed under the License is distributed on an "AS IS" BASIS, 
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
* See the License for the specific language governing permissions and 
* limitations under the License.
*
 */
package org.cafesip.gwtcomp.client.ui;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.RootPanel;

/**
 * Adds audio to GWT applications. Before calling any of the methods to play
 * a sound-bite, make sure that the static method - setRoot() has been called.
 * This is a singleton class and instance of this class can be obtained by calling
 * the getInstance() method.
 * 
 * <p>
 * <u>Examples:</u><br>
 * <ul class="example">
 * <li><a href="../../../../../../examples/org/cafesip/gwtcomp/examples/client/AudioSample.java.html">AudioSample.java</a></li>
 * </ul>
 * <p>
 * 
 * <u>Limitations:</u><br>
 * <ul class="limits">
 * <li>Works only with IE and Firefox browsers on Windows only :-(.</li>
 * </ul>
 *
 * @author Amit Chatterjee
 *
 */
public class Audio
{
    private static Audio instance = null;    
    private static RootPanel root;
    
    private HTML audioSegment;
    
    
    /**
     *  A constructor for this class.
     * 
     */
    private Audio()
    {
        init();
        instance = this;
    }
    
    /**
     * Returns the Audio singleton object.
     * 
     * @return the instance of the Audio object
     */
    public static Audio getInstance()
    {
        if (instance == null)
        {
            new Audio();
        }
        
        return instance;
    }
    
    /**
     * Sets the RootPanel object for the GWT application. This method must be
     * called prior to any play...() methods.
     * 
     * @param root the RootPanel object.
     */
    public static void setRoot(RootPanel root)
    {
        Audio.root = root;
    }

    private void init()
    {
        audioSegment = new HTML("");
        root.add(audioSegment);
    }
     
    /**
     * Plays an "error" sound.
     */
    public void playError()
    {
        play(GWT.getModuleBaseURL() + "gwtcomp-audio/error.wav");
    }
    
    /**
     * Plays a "warning" sound.
     */
    public void playWarning()
    {
        play(GWT.getModuleBaseURL() + "gwtcomp-audio/warning.wav");
    }
    
    /**
     * Plays an audio file. The format must be supported by the browser - a WAV file
     * works for all GWT-supported browsers.
     * 
     * @param url URL of the audio file.
     */
    public void play (String url)
    {
        if (audioSegment == null)
        {
            return;
        }
        
        audioSegment.setHTML(
        "<embed src='" +
        url + "' autostart='true' hidden='true' loop='0'/>");
    }
}
