/*
 * Created on Jan 19, 2008
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.FlowPanel;

/**
 * A panel for buttons. At the top/bottom of a form (that lets users enter
 * data), normally a set of buttons are presented to the user to submit, cancel,
 * etc. This panel serves as a container for the buttons. There is nothing
 * special about this except that a common set of styles can be applied to the
 * panel and the buttons. It is used internally by the
 * {@link org.cafesip.gwtcomp.client.ui.WizardPanel},
 * {@link org.cafesip.gwtcomp.client.ui.DataEntryPanel} and other widgtes.
 * <p>
 * <u>CSS Style Rules:</u>
 * <ul class="css">
 * <li>.gwtcomp-ButtonPanel { } - style for thes panel</li>
 * <li>.gwtcomp-Button { } - style for the buttons</li>
 * </ul>
 * 
 * @author Amit Chatterjee
 * 
 */
public class ButtonPanel extends FlowPanel
{
    /**
     * A constructor for this class.
     * 
     */
    public ButtonPanel()
    {
        super();
        setWidth("100%");
        setStyleName("gwtcomp-ButtonPanel");
    }

    /**
     * Add a button.
     * 
     * @param button
     *            button to add
     */
    public void addButton(Button button)
    {
        button.setStyleName("gwtcomp-ButtonPanel-Button");
        add(button);
    }

    /**
     * Remove a button.
     * 
     * @param button
     *            button to remove.
     */
    public void removeButton(Button button)
    {
        remove(button);
    }
}
