/*
 * Created on Aug 6, 2006
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import java.util.Comparator;

import com.google.gwt.user.client.ui.HasHorizontalAlignment;
import com.google.gwt.user.client.ui.HasVerticalAlignment;
import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.user.client.ui.HasHorizontalAlignment.HorizontalAlignmentConstant;
import com.google.gwt.user.client.ui.HasVerticalAlignment.VerticalAlignmentConstant;

/**
 * Helper class for the SuperTable class.
 * 
 * @author Amit Chatterjee
 * 
 */
public class ColumnProperty
{
    private String header;

    private Comparator<Widget[]> ascendingSortComparator;

    private Comparator<Widget[]> descendingSortComparator;

    private boolean displayed = true;

    private boolean selected = false;

    private String width;

    private HorizontalAlignmentConstant horizontalAlignment = 
        HasHorizontalAlignment.ALIGN_LEFT;
    
    private VerticalAlignmentConstant verticalAlignment =
        HasVerticalAlignment.ALIGN_TOP;

    /**
     * A constructor for this class.
     * 
     * @param header
     *            column header.
     * @param ascendingSortComparator
     *            ascending comparator class for the column. If this value is
     *            set to null, the "ascending sort" icon is not displayed.
     * 
     * @param descendingSortComparator
     *            descending comparator class for the column. If this value is
     *            set to null, the "descending sort" icon is not displayed.
     */
    public ColumnProperty(String header,
            Comparator<Widget[]> ascendingSortComparator,
            Comparator<Widget[]> descendingSortComparator)
    {
        this.header = header;
        this.ascendingSortComparator = ascendingSortComparator;
        this.descendingSortComparator = descendingSortComparator;
    }

    /**
     * Returns the ascendingSortComparator.
     * 
     * @return returns the ascending comparator object
     */
    public Comparator<Widget[]> getAscendingSortComparator()
    {
        return ascendingSortComparator;
    }

    /**
     * Returns the column header.
     * 
     * @return returns the header
     */
    public String getHeader()
    {
        return header;
    }

    /**
     * Returns the descendingSortComparator.
     * 
     * @return returns the descending comparator object
     */
    public Comparator<Widget[]> getDescendingSortComparator()
    {
        return descendingSortComparator;
    }

    public boolean isDisplayed()
    {
        return displayed;
    }

    public void setDisplayed(boolean displayed)
    {
        this.displayed = displayed;
    }

    /**
     * 
     * @return Returns the width.
     */
    public String getWidth()
    {
        return width;
    }

    /**
     * @param width
     *            The width to set.
     */
    public void setWidth(String width)
    {
        this.width = width;
    }

    /**
     * @return Returns the selected.
     */
    public boolean isSelected()
    {
        return selected;
    }

    /**
     * @param selected
     *            The selected to set.
     */
    public void setSelected(boolean selected)
    {
        this.selected = selected;
    }

    /**
     * @return Returns the horizontalAlignment.
     */
    public HorizontalAlignmentConstant getHorizontalAlignment()
    {
        return horizontalAlignment;
    }

    /**
     * @param horizontalAlignment The horizontalAlignment to set.
     */
    public void setHorizontalAlignment(
            HorizontalAlignmentConstant horizontalAlignment)
    {
        this.horizontalAlignment = horizontalAlignment;
    }

    /**
     * @return Returns the verticalAlignment.
     */
    public VerticalAlignmentConstant getVerticalAlignment()
    {
        return verticalAlignment;
    }

    /**
     * @param verticalAlignment The verticalAlignment to set.
     */
    public void setVerticalAlignment(VerticalAlignmentConstant verticalAlignment)
    {
        this.verticalAlignment = verticalAlignment;
    }

}
