/*
 * Created on Sep 8, 2007
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import org.cafesip.gwtcomp.client.utils.HTMLHelper;

import com.google.gwt.user.client.ui.HTML;

/**
 * A label object that can be dragged and dropped into a
 * {@link org.cafesip.gwtcomp.client.ui.DroppableList}. The label consists of a
 * name and optionally, an icon to the left of the name. This label can be
 * dragged by holding the mouse button down and by moving the pointer. The
 * object can be dropped into a DroppableList object.
 * 
 * <p>
 * The draggable/droppable classes use the scriptaculous javascript library for
 * providing the functionality. Therefore, you must add the following segment to
 * your application HTML file (see the GWTCompExamples.html for an example).
 * 
 * <pre>
 *       &lt;script src=&quot;gwtcomp-scripts/scriptaculous/prototype.js&quot; type=&quot;text/javascript&quot;&gt;&lt;/script&gt;
 *       &lt;script src=&quot;gwtcomp-scripts/scriptaculous/scriptaculous.js&quot; type=&quot;text/javascript&quot;&gt;&lt;/script&gt;
 *       &lt;script src=&quot;gwtcomp-scripts/scriptaculous/dragdrop.js&quot; type=&quot;text/javascript&quot;&gt;&lt;/script&gt;
 * </pre>
 * <p>
 * 
 * <u>Examples:</u><br>
 * <ul class="example">
 * <li><a
 * href="../../../../../../examples/org/cafesip/gwtcomp/examples/client/DraggableSample.java.html">DraggableSample.java</a></li>
 * </ul>
 * 
 * <p>
 * <u>CSS Style Rules:</u>
 * <ul class="css">
 * <li>.gwtcomp-DraggableLabel { } - style for the label</li>
 * </ul>
 * 
 * <p>
 * <u>Screen-Shots:</u><br>
 * <img class='gallery'
 * src='../../../../../../screen-shots/draggable_label.gif'/>
 * <p>
 * 
 * @author Amit Chatterjee
 * 
 */
public class DraggableLabel extends HTML
{
    private String imageUrl;

    private String name;

    private String id;

    private String clazz;

    Draggable drag = null;

    /**
     * A constructor for this class that displays an icon and a text label.
     * 
     * @param imageUrl
     *            The URL of the icon.
     * @param name
     *            The text of the label.
     * @param id
     *            The DOM id of this object. It must be unique. See the
     *            description for
     *            {@link org.cafesip.gwtcomp.client.ui.Draggable} for details.
     * @param clazz
     *            The class value for this label. See the description for
     *            {@link org.cafesip.gwtcomp.client.ui.Draggable} for details.
     */
    public DraggableLabel(String imageUrl, String name, String id, String clazz)
    {
        super(imageUrl == null ? name : HTMLHelper
                .imageWithText(imageUrl, name), false);
        setStyleName("gwtcomp-DraggableLabel");
        this.imageUrl = imageUrl;
        this.name = name;
        this.id = id;
        this.clazz = clazz;
    }

    /**
     * A constructor for this class with just the text label (no icon).
     * 
     * @param name
     *            The text of the label.
     * @param id
     *            The DOM id of this object. It must be unique. See the
     *            description for
     *            {@link org.cafesip.gwtcomp.client.ui.Draggable} for details.
     * @param clazz
     *            The class value for this label. See the description for
     *            {@link org.cafesip.gwtcomp.client.ui.Draggable} for details.
     */
    public DraggableLabel(String name, String id, String clazz)
    {
        this(null, name, id, clazz);
    }

    /*
     * @see com.google.gwt.user.client.ui.Widget#onLoad()
     */
    protected void onLoad()
    {
        drag = Draggable.makeDraggable(this, name, id, clazz);
    }

    /*
     * @see com.google.gwt.user.client.ui.Widget#onUnload()
     */
    protected void onUnload()
    {
        if (drag != null)
        {
            drag.dispose();
            drag = null;
        }
    }

    /**
     * @return Returns the imageUrl.
     */
    public String getImageUrl()
    {
        return imageUrl;
    }
}
