/**
 * 
 */
package org.cafesip.gwtcomp.client.ui;

import java.util.ArrayList;
import java.util.Iterator;

import com.google.gwt.user.client.Event;
import com.google.gwt.user.client.ui.FileUpload;

/**
 * An extension of the GWT FileUpload class that allows applications to listen to
 * file upload events. This allows applications to listens to events such has
 * when an upload file is entered (or selected from the "browse" popup). Applications
 * can use the listeners to perform validation or apply other business logic.
 * 
 * <p>
 * <u>Examples:</u><br>
 * <ul class="example">
 * <li><a href="../../../../../../examples/org/cafesip/gwtcomp/examples/client/ImageUploadPanel.java.html">ImageUploadPanel.java</a></li>
 * </ul>
 * 
 * <p>
 * <u>Screen-Shots:</u><br>
 * <img class='gallery' src='../../../../../../screen-shots/eventful_file_upload.gif'/>
 *
 * @author Amit Chatterjee
 *
 */
public class EventfulFileUpload extends FileUpload
{
    private ArrayList<FileUploadEventListener> events = new ArrayList<FileUploadEventListener>();
    
    /**
     *  A constructor for this class.
     * 
     */
    public EventfulFileUpload()
    {
        super();
        sinkEvents(Event.ONCHANGE | Event.ONKEYUP);
    }

    /**
     * Add a file upload listener.
     * 
     * @param listener The listener object.
     */
    public void addEventListener(FileUploadEventListener listener)
    {
        events.add(listener);
    }
    
    /*
     * @see com.google.gwt.user.client.ui.Widget#onBrowserEvent(com.google.gwt.user.client.Event)
     */
    public final void onBrowserEvent(Event event)
    {
        Iterator<FileUploadEventListener> i = events.iterator();
        while (i.hasNext())
        {
            FileUploadEventListener listener = i.next();
            listener.onEvent(event);
        }
        
        super.onBrowserEvent(event);
    }    
}
