/*
 * Created on Sep 3, 2007
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import com.google.gwt.user.client.ui.Widget;

/**
 * This interface must be implemented by applications to add a listener to the {@link org.cafesip.gwtcomp.client.ui.SuperTable} 
 * class.
 * 
 * @author Amit Chatterjee
 *
 */
public interface SuperTableListener
{
    /**
     * Invoked if a row is selected or deselected. Multiple rows can be set in a super table.
     * 
     * @param selected selected or deselected.
     * @param row row index
     * @param columns the row including all the columns.
     */
    public void rowSelected(boolean selected, int row, Widget[] columns);
    
    /**
     * Invoked if a cell is selected. Only one cell can remain selected at a time.
     * Therefore, when this method is invoked and the selected parameter is set to true,
     * the previous selection is assumed to cleared. There is no separate invocation for
     * the previously-selected cell. A deselection invocation is only made if the selected
     * row has been deselected by the user by clicking on it again.
     * 
     * @param selected selected or deselected.
     * @param row row index
     * @param col column index
     * @param column the column widget.
     */
    public void cellSelected (boolean selected, int row, int col, Widget column);
}
