/*
 * Created on Sep 7, 2007
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import com.google.gwt.user.client.ui.TreeItem;

/**
 * This interface must be implemented by applications to register a super tree
 * listener object. See the {@link org.cafesip.gwtcomp.client.ui.SuperTree}
 * class for details.
 * 
 * @author Amit Chatterjee
 * 
 */
public interface SuperTreeListener
{
    /**
     * This method is invoked just before a popup menu is popped up. The
     * application can hide menu items, add new menu items, etc. by implementing
     * this method.
     * 
     * @param level
     *            the selected level.
     * @param menu
     *            the menu that will be popped up.
     * @param treeItems
     *            selected tree items.
     */
    public void onPopup(String level, PopupMenu menu, TreeItem[] treeItems);

    /**
     * Invoked when one or more tree items are selected. Note that this method
     * is only invoked, when there is no popup menu associated with the element
     * and there is no popup menu associated with the level.
     * 
     * @param level
     *            level of the item
     * @param treeItems
     *            selected tree items
     */
    public void onSelect(String level, TreeItem[] treeItems);

    /**
     * This method is invoked when a tree item is expanded.
     * 
     * @param item
     *            the tree item.
     */
    public void onExpand(TreeItem item);

    /**
     * This method is invoked when a tree item is collapsed.
     * 
     * @param item
     *            the tree item.
     */
    public void onCollapse(TreeItem item);
}
