/*
 * Created on Aug 18, 2007
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui;

import java.util.ArrayList;

import com.google.gwt.user.client.ui.AbsolutePanel;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.Image;
import com.google.gwt.user.client.ui.Widget;

/**
 * The toolbar is a simple panel widget that is used to place one or more
 * "tools" into it. A tool can be an image, or any widget. Applications are
 * responsible for setting tool-tips, event listeners, etc. A toolbar can
 * be placed inside a {@link org.cafesip.gwtcomp.client.ui.ToolbarPanel}.
 * 
 * <p>
 * <u>Examples:</u><br>
 * <ul class="example">
 * <li><a
 * href="../../../../../../examples/org/cafesip/gwtcomp/examples/client/MiscWidgetsSample.java.html">MiscWidgetsSample.java</a></li>
 * </ul>
 * 
 * <p>
 * <u>CSS Style Rules:</u>
 * <ul class="css">
 * <li>.gwtcomp-Toolbar { } - style for the toolbar itself</li>
 * <li>.gwtcomp-Toolbar-Image { } - style for any Image inside the toolbar</li>
 * </ul>
 * 
 * <p>
 * <u>Screen-Shots:</u><br>
 * <img class='gallery' src='../../../../../../screen-shots/toolbar.gif'/>
 * <p>
 * 
 * @author Amit Chatterjee
 * 
 */
public class Toolbar extends Composite
{
    private AbsolutePanel panel;

    private int horizontalSpacing = 10;

    private int verticalSpacing = 5;

    private ArrayList<Widget> list = new ArrayList<Widget>();

    /**
     *  A constructor for this class.
     * 
     */
    public Toolbar()
    {
        panel = new AbsolutePanel();
        initWidget(panel);

        panel.addStyleName("gwtcomp-Toolbar");
    }

    /**
     * Adds a "tool" widget into the toolbar.
     * @param w widget to add.
     */
    public void addWidget(Widget w)
    {
        list.add(w);
        panel.add(w);

        if (w instanceof Image)
        {
            w.addStyleName("gwtcomp-Toolbar-Image");
        }
    }

    /**
     * Returns the horizontal spacing in pixels.
     * 
     * @return Returns the horizontalSpacing.
     */
    public int getHorizontalSpacing()
    {
        return horizontalSpacing;
    }

    /**
     * Sets the horizontal spacing between the tools in the toolbar.
     * 
     * @param horizontalSpacing
     *            The horizontalSpacing to set.
     */
    public void setHorizontalSpacing(int horizontalSpacing)
    {
        this.horizontalSpacing = horizontalSpacing;
    }

    /**
     * Returns the vertical spacing (top and bottom).
     * 
     * @return Returns the verticalSpacing.
     */
    public int getVerticalSpacing()
    {
        return verticalSpacing;
    }

    /**
     * Sets the vertical spacing.
     * 
     * @param verticalSpacing
     *            The verticalSpacing to set.
     */
    public void setVerticalSpacing(int verticalSpacing)
    {
        this.verticalSpacing = verticalSpacing;
    }

    /**
     * Redraw the toolbar. This is needed in some cases when the size of the tools widgets
     * changes.
     */
    public void redraw()
    {
        int left = horizontalSpacing;
        int top = verticalSpacing;
        int max = 0;

        int size = list.size();
        for (int i = 0; i < size; i++)
        {
            Widget w = list.get(i);
            panel.setWidgetPosition(w, left, top);
            left += w.getOffsetWidth() + horizontalSpacing;

            if (w.getOffsetHeight() > max)
            {
                max = w.getOffsetHeight();
            }
        }

        setHeight((max + verticalSpacing + verticalSpacing) + "px");
        setWidth(left + horizontalSpacing + "px");
        // System.out.println("toolbar attached. h=" + max + ", w=" + left);
    }
}
