/*
 * Created on Dec 3, 2008
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.ui.charting;

import java.util.Date;

import org.cafesip.gwtcomp.client.common.ChartInfo;
import org.cafesip.gwtcomp.client.common.SeriesInfo;
import org.cafesip.gwtcomp.client.common.TimeSeriesPlotInfo;
import org.cafesip.gwtcomp.client.utils.HTMLHelper;

import com.googlecode.gchart.client.GChart;

/**
 * An internal class for rendering the chart in the LiveDataPanel.
 * 
 * @author Amit Chatterjee
 * 
 */
public class TimeSeriesChartPanel extends GChart
{
    private static final int MAX_POINTS = 20;
    
    private ChartInfo chartInfo;

    private int seriesCount;
    
    private int pointCount = 0;

    public TimeSeriesChartPanel(ChartInfo chartInfo, int width, int height)
    {
        super();
        
        this.chartInfo = chartInfo;

        setChartTitle(HTMLHelper.header(3, chartInfo.getTitle()));
        setChartSize(width, height);

        TimeSeriesPlotInfo ts = (TimeSeriesPlotInfo) chartInfo.getPlot();
        SeriesInfo[] serie = ts.getSeries();
        seriesCount = serie.length;

        for (int i = 0; i < seriesCount; i++)
        {
            addCurve();
            getCurve().setYAxis(Y_AXIS);

            // solid, 1px thick, 1px resolution, connecting lines:
            getCurve().getSymbol().setSymbolType(SymbolType.LINE);
            getCurve().getSymbol().setFillThickness(1);
            getCurve().getSymbol().setFillSpacing(1);

            // Make center-fill of square point markers same color as line:
            getCurve().getSymbol().setBackgroundColor(
                    getCurve(0).getSymbol().getBorderColor());

            if (chartInfo.isDisplayLegend())
            {
                getCurve().setLegendLabel(serie[i].getName());
            }

            getXAxis().setAxisLabel("Time");
            getYAxis().setAxisLabel(ts.getYLabel());

            getXAxis().setHasGridlines(true);
            getXAxis().setTickLabelFormat("=(Date)HH:mm:ss");
            getXAxis().setTickCount(ts.getNumXTicks());

            getYAxis().setHasGridlines(true);
            getYAxis().setTickLabelFormat("###");
            getYAxis().setTickCount(ts.getNumYTicks());
            getYAxis().setAxisMin(ts.getMinValue());
            getYAxis().setAxisMax(ts.getMaxValue());
        }
        
        update();
    }

    public void addPoints(Date timestamp, Double[] values)
    {
        for (int i = 0; i < values.length; i++)
        {
            if (values[i] == null)
            {
                continue;
            }
            
            getCurve(i).addPoint(timestamp.getTime(), values[i].doubleValue());
        }
        
        // TODO - this logic will have to be revisited because if there
        // are null points, they should not be removed.
        if (pointCount++ > MAX_POINTS)
        {
            for (int i = 0; i < seriesCount; i++)
            {
                getCurve(i).removePoint(0);
            }
        }
        
        pointCount++;        
    }

    /**
     * @return Returns the chartInfo.
     */
    public ChartInfo getChartInfo()
    {
        return chartInfo;
    }
}
