/*
 * Created on Oct 14, 2007
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.client.utils;

import java.util.Comparator;

import com.google.gwt.user.client.ui.Widget;

/**
 * A convenience class for the
 * {@link org.cafesip.gwtcomp.client.ui.SuperTableProperty}. The SuperTable
 * supports sorting of columns but you have to provide the comparator. This is a
 * ready-made comparator class that you can use to compare columns that are of
 * the type GWT Label or HTML and needs a numeric (int and float) comparison.
 * 
 * @author Amit Chatterjee
 * 
 */
public class NumericComparator implements Comparator<Widget[]>
{
    private int col;

    private boolean ascending;

    /**
     * 
     * A constructor for this class.
     * 
     * @param col
     *            Specifies the column index in the table (whether it is column
     *            0, 1 , 2 etc.)
     * @param ascending
     *            true if ascending comparator, false if this is a descending
     *            comparator.
     */
    public NumericComparator(int col, boolean ascending)
    {
        this.col = col;
        this.ascending = ascending;
    }

    /*
     * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
     */
    public int compare(Widget[] o1, Widget[] o2)
    {
        Widget w1 = o1[col];
        Widget w2 = o2[col];
        
        String t1 = StringComparator.convertToText(w1);
        String t2 = StringComparator.convertToText(w2);
                
        if (ascending)
        {      
            return (int) (Float.parseFloat(t1) - Float.parseFloat(t2)); 
        }
        else
        {
            return (int) (Float.parseFloat(t2) - Float.parseFloat(t1));                       
        }
    }
}
