package org.cafesip.gwtcomp.client.validators;

/**
 * This class is used to validate telephone number that the user enters. It can be
 * used from GWT client-side classes to validate user-entered phone numbers.
 * 
 * @author Beck McElroy
 *
 */
public class PhoneNumberValidator
{
    /**
     * Validate the given phone number.
     * 
     * @param phone phone number
     * @return true if the validation is successful, false otherwise
     */
    public static boolean validPhoneNumber(String phone)
    {
        int len = phone.length();
        int digit_count = 0;
        boolean bracket_opened = false;

        // the valid characters are digits, "+" (first character), "-", " ", "(" and ")"
        for (int i = 0; i < len; i++)
        {
            char c = phone.charAt(i);
            if (Character.isDigit(c) == true)
            {
                digit_count++;
            }
            else if (c == '+')
            {
                if (i > 0)
                {
                    return false;
                }
            }
            else if (c == '#')
            {
                digit_count++;
            }
            else if (c == '*')
            {
                digit_count++;
            }
            else if ((c == '-') || (c == ' '))
            {
                // do nothing
            }
            else if (c == '(')
            {
                if (bracket_opened == true)
                {
                    // nested brackets are not allowed
                    return false;
                }

                bracket_opened = true;
            }
            else if (c == ')')
            {
                if (bracket_opened == false)
                {
                    // a close bracket without an open bracket
                    return false;
                }

                bracket_opened = false;
            }
            else
            {
                return false;
            }
        }

        if (bracket_opened == true)
        {
            // bracket opened but not closed
            return false;
        }

        if (digit_count < 2)
        {
            return false;
        }

        return true;
    }
}
