/*
 * Created on Jul 19, 2006
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.server;

import java.io.File;
import java.io.FileFilter;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;

import org.cafesip.gwtcomp.client.common.DirListingService;
import org.cafesip.gwtcomp.client.common.DirectoryElement;
import org.cafesip.gwtcomp.client.common.FileElement;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

/**
 * GWT servlet for handling RPC calls for ServerFileBrowser
 * org.cafesip.gwtcomp.client.ui.ServerFileBrowser) widget. It is required for
 * the functioning of the ServerFileBrowser and is not needed for application
 * developer.
 * 
 * @author Amit Chatterjee
 * 
 */
public class DirListingServiceImpl extends RemoteServiceServlet implements
        DirListingService
{
    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = 4872759117118551989L;

    /*
     * @see org.cafesip.gwtcomp.client.common.DirListingService#list(java.lang.String,
     *      java.lang.String)
     */
    public DirectoryElement list(String directory, String filter)
            throws Exception
    {
        if ((directory == null) || (directory.trim().length() == 0))
        {
            directory = System.getProperty("user.home");
        }
        else if (directory.endsWith("..") == true)
        {
            File f = new File(directory.substring(0, directory.length() - 2));
            directory = f.getParentFile().getAbsolutePath();
        }

        File dir = new File(directory);

        if (dir.isDirectory() == false)
        {
            throw new Exception(directory + " is not a directory");
        }

        class MyFileFilter implements FileFilter
        {
            private String filter;

            public MyFileFilter(String filter)
            {
                this.filter = filter;
            }

            public boolean accept(File path)
            {
                try
                {
                    if (filter == null)
                    {
                        return true;
                    }

                    if (path.isDirectory() == true)
                    {
                        return true;
                    }

                    return path.getName().matches(filter);
                }
                catch (Exception e)
                {
                    e.printStackTrace();
                    return false;
                }
            }

        }

        File[] files = dir.listFiles(new MyFileFilter(filter));

        ArrayList<FileElement> list = new ArrayList<FileElement>();
        SimpleDateFormat dformatter = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        for (int i = 0; i < files.length; i++)
        {
            if ((files[i].getName().equals(".") == true)
                    || (files[i].getName().equals("..") == true))
            {
                continue;
            }

            String type = null;
            StringBuffer perms = new StringBuffer();
            if (files[i].isDirectory() == true)
            {
                type = FileElement.DIR;
                perms.append(FileElement.DIR);
            }
            else
            {
                type = FileElement.FILE;
                perms.append(FileElement.FILE);
            }

            if (files[i].canRead() == true)
            {
                perms.append("r");
            }
            else
            {
                perms.append("-");
            }

            if (files[i].canWrite() == true)
            {
                perms.append("w");
            }
            else
            {
                perms.append("-");
            }

            FileElement f = new FileElement();
            f.init(files[i].getName(), type, dformatter.format(new Date(
                    files[i].lastModified())), perms.toString());
            list.add(f);
        }

        // sort the files
        Collections.sort(list, new Comparator<FileElement>()
        {
            public int compare(FileElement e1, FileElement e2)
            {
                if (e1.getType().equals(FileElement.DIR) == true)
                {
                    if (e2.getType().equals(FileElement.FILE) == true)
                    {
                        return -1;
                    }

                    return e1.getName().compareTo(e2.getName());

                }

                if (e2.getType().equals(FileElement.DIR) == true)
                {
                    return 1;
                }

                return e1.getName().compareTo(e2.getName());
            }
        });

        FileElement[] elements = new FileElement[list.size()];
        list.toArray(elements);

        DirectoryElement d = new DirectoryElement();
        d.init(dir.getAbsolutePath(), elements, File.separator);
        return d;
    }
}
