/*
 * Created on Feb 7, 2009
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.server;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

import org.cafesip.gwtcomp.client.common.ChartInfo;

/**
 * This class contains information about a live data session.
 * The application can use this information to look for a 
 * deliver the data for rendering in charts. The userAttributes
 * attribute allows the application to add its own attributes.
 * 
 * @author Amit Chatterjee
 * 
 */
public class LiveDataSessionInfo implements Serializable
{
    private static final long serialVersionUID = 1498904789704367828L;

    private String context;

    private String instance;

    private String param;

    private ChartInfo chartInfo;

    private Date lastCollection;

    private int deliveryCount;

    private HashMap<String, Object> userAttributes = new HashMap<String, Object>();

    /**
     * A constructor for this class.
     * 
     * @param context
     * @param instance
     * @param param
     * @param chartInfo
     * @param lastCollection
     * @param deliveryCount
     */
    public LiveDataSessionInfo(String context, String instance, String param,
            ChartInfo chartInfo, Date lastCollection, int deliveryCount)
    {
        super();
        this.context = context;
        this.instance = instance;
        this.param = param;
        this.chartInfo = chartInfo;
        this.lastCollection = lastCollection;
        this.deliveryCount = deliveryCount;
    }

    /**
     * 
     * A constructor for this class.
     * 
     */
    public LiveDataSessionInfo()
    {
    }

    /**
     * @return Returns the context.
     */
    public String getContext()
    {
        return context;
    }

    /**
     * @param context
     *            The context to set.
     */
    public void setContext(String context)
    {
        this.context = context;
    }

    /**
     * @return Returns the instance.
     */
    public String getInstance()
    {
        return instance;
    }

    /**
     * @param instance
     *            The instance to set.
     */
    public void setInstance(String instance)
    {
        this.instance = instance;
    }

    /**
     * @return Returns the param.
     */
    public String getParam()
    {
        return param;
    }

    /**
     * @param param
     *            The param to set.
     */
    public void setParam(String param)
    {
        this.param = param;
    }

    /**
     * @return Returns the chartInfo.
     */
    public ChartInfo getChartInfo()
    {
        return chartInfo;
    }

    /**
     * @param chartInfo
     *            The chartInfo to set.
     */
    public void setChartInfo(ChartInfo chartInfo)
    {
        this.chartInfo = chartInfo;
    }

    /**
     * @return Returns the lastCollection.
     */
    public Date getLastCollection()
    {
        return lastCollection;
    }

    /**
     * @param lastCollection
     *            The lastCollection to set.
     */
    public void setLastCollection(Date lastCollection)
    {
        this.lastCollection = lastCollection;
    }

    /**
     * @return Returns the deliveryCount.
     */
    public int getDeliveryCount()
    {
        return deliveryCount;
    }

    /**
     * @param deliveryCount
     *            The deliveryCount to set.
     */
    public void setDeliveryCount(int deliveryCount)
    {
        this.deliveryCount = deliveryCount;
    }

    /**
     * @return Returns the userAttributes.
     */
    public HashMap<String, Object> getUserAttributes()
    {
        return userAttributes;
    }

    /**
     * @param userAttributes
     *            The userAttributes to set.
     */
    public void setUserAttributes(HashMap<String, Object> userAttributes)
    {
        this.userAttributes = userAttributes;
    }

    /**
     * Returns an user attribute.
     * @param name
     * @return
     */
    public Object getAttribute(String name)
    {
        return userAttributes.get(name);
    }

    /**
     * Sets an user attribute.
     * 
     * @param name
     * @param value
     */
    public void setAttribute(String name, Object value)
    {
        userAttributes.put(name, value);
    }

    /**
     * Removes an user attribute.
     * 
     * @param name
     */
    public void removeAttribute(String name)
    {
        userAttributes.remove(name);
    }

}
