/*
 * Created on Mar 27, 2008
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.server;

import java.security.Principal;

import javax.servlet.http.HttpSession;

import org.cafesip.gwtcomp.client.common.ChartData;
import org.cafesip.gwtcomp.client.common.ChartInitData;

/**
 * This interface must be implemented by the "data source" class that provides
 * data to one or more
 * {@link org.cafesip.gwtcomp.client.ui.charting.LiveDataPanel} objects for your
 * GWT application. The methods in this class are invoked by the
 * {@link org.cafesip.gwtcomp.server.LiveDataServiceImpl} servlet during initial
 * data fetch and subsequently when a refresh request is received from the
 * client-side.
 * 
 * @author Amit Chatterjee
 * 
 */
public interface LiveDataSource
{
    /**
     * This method is invoked by the
     * {@link org.cafesip.gwtcomp.server.LiveDataServiceImpl} servlet when the
     * chart is intialized at the client-side. The method must return a
     * ChartInitData object that specifies the property of the chart and the
     * initial data. The client-side of the application displays the chart and
     * the data accordingly.
     * 
     * @param user
     *            the user who is displaying the live data panel. The parameter
     *            has a null value of the user has not been authenticated by the
     *            servlet container.
     * @param session
     *            the HTTPSession object is passed so that you application can
     *            use session-scope variables to maintain states.
     * @param sessionData
     *            Session data.
     * @return the ChartInitData object
     */
    public ChartInitData getChartInfoAndInitialData(Principal user,
            HttpSession session, LiveDataSessionInfo sessionData);

    /**
     * This method is invoked by the
     * {@link org.cafesip.gwtcomp.server.LiveDataServiceImpl} servlet
     * periodically to retrieve data that is used to refresh the live data
     * panel. The method returns the ChartData object that contains the data.
     * 
     * @param user
     *            the user who is displaying the live data panel. The parameter
     *            has a null value of the user has not been authenticated by the
     *            servlet container.
     * @param session
     *            the HTTPSession object is passed so that you application can
     *            use session-scope variables to maintain states.
     * @param sessionData
     *            Information on the session.
     * 
     * @return the chart data
     */
    public ChartData getNextData(Principal user, HttpSession session,
            LiveDataSessionInfo sessionData);
    
    /**
     * This method is invoked by the
     * {@link org.cafesip.gwtcomp.server.LiveDataServiceImpl} servlet
     * to information the data source that the session is closed. This
     * gives the application a chance to perform cleanup.
     *  
     * @param user
     *            the user who is displaying the live data panel. The parameter
     *            has a null value of the user has not been authenticated by the
     *            servlet container.
     * @param session
     *            the HTTPSession object is passed so that you application can
     *            use session-scope variables to maintain states.
     * @param sessionData
     *            Information on the session.
     */
    public void close(Principal user, HttpSession session,
            LiveDataSessionInfo sessionData);
}
