/*
 * Created on Feb 7, 2009
 * 
 * Copyright 2005 CafeSip.org 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *	http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 */
package org.cafesip.gwtcomp.server;

import java.util.HashMap;

import javax.servlet.http.HttpSession;

/**
 * @author Amit Chatterjee
 * 
 */
public class LiveDataSourceSession
{
    private static final String SESSIONS_INFO = "org.cafesip.gwtcomp.charting.dataSourceSessions";

    private static final String SESSION_ID = "org.cafesip.gwtcomp.charting.dataSourceSessionId";

    public static LiveDataSessionInfo getSession(int sessionId,
            HttpSession session)
    {
        if (session == null)
        {
            return null;
        }

        HashMap<Integer, LiveDataSessionInfo> sessions = (HashMap<Integer, LiveDataSessionInfo>) session
                .getAttribute(SESSIONS_INFO);
        if (sessions == null)
        {
            return null;
        }
        return sessions.get(sessionId);
    }

    public static int addSession(LiveDataSessionInfo sessionData,
            HttpSession session)
    {
        HashMap<Integer, LiveDataSessionInfo> sessions = (HashMap<Integer, LiveDataSessionInfo>) session
                .getAttribute(SESSIONS_INFO);
        if (sessions == null)
        {
            sessions = new HashMap<Integer, LiveDataSessionInfo>();
            session.setAttribute(SESSIONS_INFO, sessions);
        }

        int session_id = nextSessionId(session);
        sessions.put(session_id, sessionData);
        return session_id;
    }

    public static void removeSession(int sessionId, HttpSession session)
    {
        HashMap<Integer, LiveDataSessionInfo> sessions = (HashMap<Integer, LiveDataSessionInfo>) session
                .getAttribute(SESSIONS_INFO);
        if (sessions == null)
        {
            return;
        }
        
        sessions.remove(sessionId);
    }

    private static synchronized int nextSessionId(HttpSession session)
    {
        Integer sessionId = (Integer) session.getAttribute(SESSION_ID);
        if (sessionId == null)
        {
            sessionId = 0;
        }

        session.setAttribute(SESSION_ID, sessionId + 1);
        return sessionId;
    }
}
